#============================================================================
#	Datei:		Netzwerk.sh
#
#	Summary:	Dieses Script legt ein Netzwerk an
#
#	Datum:		2021-07-29
#
#   Revisionen: yyyy-dd-mm
#                   - ...
#	Buch:	    Azure für Dummies
#
#------------------------------------------------------------------------------
#	Geschrieben von 
#       Frank Geisler, GDS Business Intelligence GmbH
#       Dr. Benjamin Kettner, ML!PA Consulting GmbH
#
#   DIESER CODE UND DIE ENTHALTENEN INFORMATIONEN WERDEN OHNE GEWÄHR JEGLICHER
#   ART ZUR VERFÜGUNG GESTELLT, WEDER AUSDRÜCKLICH NOCH IMPLIZIT, EINSCHLIESSLICH,
#   ABER NICHT BESCHRÄNKT AUF FUNKTIONALITÄT ODER EIGNUNG FÜR EINEN BESTIMMTEN
#   ZWECK. SIE VERWENDEN DEN CODE AUF EIGENE GEFAHR.
#============================================================================*/

az group create \
   --name dummiesvnetrg \
   --location northeurope

az network vnet create \
    --resource-group dummiesvnetrg \
    --name dummiesVNet \
    --address-prefix 10.0.0.0/8 \
    --subnet-name mySubnet \
    --subnet-prefix 10.0.1.0/24 \
    --location northeurope

az network vnet subnet create \
    --vnet-name dummiesVNet \
    --name GatewaySubnet \
    --resource-group dummiesvnetrg \
    --address-prefix 10.0.2.0/27    

az network public-ip create \
    --name pip_dummies_gateway \
    --resource-group dummiesvnetrg \
    --allocation-method Dynamic \
    --location northeurope 

az network vnet-gateway create \
    --name dummiesVPNGateway \
    --location northeurope \
    --public-ip-address pip_dummies_gateway \
    --resource-group dummiesvnetrg \
    --vnet dummiesVNet \
    --gateway-type Vpn \
    --sku VpnGw1 \
    --vpn-type RouteBased \
    --no-wait  

az network public-ip show \
    --name pip_dummies_gateway \
    --resource-group dummiesvnetrg

az network vnet-gateway show \
    --name dummiesVPNGateway \
    --resource-group dummiesvnetrg

az network local-gateway create \
    --gateway-ip-address 12.34.56.78 \
    --name gdsluedinghausen \
    --resource-group dummiesvnetrg \
    --local-address-prefixes 192.168.1.0/24 192.168.2.0/24 \
    --location northeurope

az network vpn-connection create \
    --name con_lh \
    --resource-group dummiesvnetrg \
    --vnet-gateway1 dummiesVPNGateway \
    --location northeurope \
    --shared-key test123456789 \
    --local-gateway2 gdsluedinghausen

az network vnet create \
    --resource-group dummiesvnetrg \
    --name dummiesVNet2 \
    --address-prefix 192.168.0.0/16 \
    --subnet-name mySubnet \
    --subnet-prefix 192.168.10.0/24 \
    --location northeurope

# Get the id for VNet1.
dummiesVNetId=$(az network vnet show \
                  --resource-group dummiesvnetrg \
                  --name Vnet1 \
                  --query id \
                  --out tsv)

# Get the id for VNet2.
dummiesVNet2Id=$(az network vnet show \
                      --resource-group dummiesvnetrg \
                      --name dummiesVNet2 \
                      --query id \
                      --out tsv)

# Peer VNet1 to VNet2.
az network vnet peering create \
  --name LinkDummiesVNetToDummiesVNet2 \
  --resource-group dummiesvnetrg \
  --vnet-name dummiesVNet \
  --remote-vnet-id $dummiesVNet2Id \
  --allow-vnet-access

# Peer VNet2 to VNet1.
az network vnet peering create \
  --name LinkDummies2VNetToDummiesVNet \
  --resource-group dummiesvnetrg \
  --vnet-name dummiesVNet2 \
  --remote-vnet-id $dummiesVNetId \
  --allow-vnet-access

az network nsg create \
    --resource-group dummiesvnetrg \
    --name WindowsServersNSG \
    --location northeurope

az network vnet subnet update \
    --resource-group dummiesvnetrg \
    --name MySubnet \
    --vnet-name dummiesVNet2 \
    --network-security-group WindowsServersNSG    

az network nsg rule create \
    --resource-group dummiesvnetrg \
    --nsg-name WindowsServersNSG \
    --name RDPzulassen \
    --direction Inbound \
    --priority 100 \
    --source-address-prefixes '*' \
    --source-port-ranges '*' \
    --destination-address-prefixes '*' \
    --destination-port-ranges 3389 \
    --access Allow \
    --protocol Tcp \
    --description "RDP Protokoll zulassen"

    