#============================================================================
#	Datei:		Virtuelle Maschine erstellen.ps1
#
#	Summary:	Dieses Script erstellt eine virtuelle Maschine in Azure
#
#	Datum:		2021-07-28
#
#   Revisionen: yyyy-dd-mm
#                   - ...
#	Buch:	    Azure für Dummies
#
#	PowerShell Version: 5.1
#------------------------------------------------------------------------------
#	Geschrieben von 
#       Frank Geisler, GDS Business Intelligence GmbH
#       Dr. Benjamin Kettner, ML!PA Consulting GmbH
#
#   Dieses Script ist nur zu Lehr- bzw. Lernzwecken gedacht
#
#   DIESER CODE UND DIE ENTHALTENEN INFORMATIONEN WERDEN OHNE GEWÄHR JEGLICHER
#   ART ZUR VERFÜGUNG GESTELLT, WEDER AUSDRÜCKLICH NOCH IMPLIZIT, EINSCHLIESSLICH,
#   ABER NICHT BESCHRÄNKT AUF FUNKTIONALITÄT ODER EIGNUNG FÜR EINEN BESTIMMTEN
#   ZWECK. SIE VERWENDEN DEN CODE AUF EIGENE GEFAHR.
#============================================================================*/


#--------------------------------------------------------------------------
# 01. - Ressourcengruppe erstellen
# -------------------------------------------------------------------------
$resourcegroupName = 'meinedummiesvm'
$location = 'North Europe'

New-AzResourceGroup `
    -Name $resourcegroupName `
    -Location $location

#----------------------------------------------------------------------------
# 02. - Storage anlegen
#      Der Name für den Storage in $storageName muss eindeutig sein.
#----------------------------------------------------------------------------

# Storage
$storageName = 'meinedummiesvm'
$storageType = 'Standard_LRS'

$storageAccount = New-AzStorageAccount `
                         -ResourceGroupName $resourcegroupName `
                         -Name $storageName `
                         -Type $StorageType `
                         -Location $location

#----------------------------------------------------------------------------
# 03. - VNet anlegen
#----------------------------------------------------------------------------

# Netzwerk
$vnetName = 'vnet-dummies'
$subNetName = 'snet-default'
$VNetAddressPrefix = '10.0.0.0/16'
$VNetSubnetAddressPrefix = '10.0.0.0/24'

$SubnetConfig = New-AzVirtualNetworkSubnetConfig `
                      -Name $subNetName `
                      -AddressPrefix $VNetSubnetAddressPrefix

$vn = New-AzVirtualNetwork `
             -Name $VNetName `
             -ResourceGroupName $ResourceGroupName `
             -Location $Location `
             -AddressPrefix $VNetAddressPrefix `
             -Subnet $SubnetConfig

#----------------------------------------------------------------------------
# 04. - Allgemeines Credential für die virtuellen Maschinen abfragen. Da 
#       die Maschinen ja eh in die Domäne gehängt werden wird nur einmal das
#       Credential abgefragt und als lokaler Admin verwendet.
#----------------------------------------------------------------------------
$Credential = Get-Credential

#--------------------------------------------------------------------------
# 05. - virtuelle Maschine dummiesvm anlegen
# -------------------------------------------------------------------------

# Compute für dummiesvm
$dummiesvm_publisherName = 'MicrosoftWindowsServer'
$dummiesvm_offer = 'WindowsServer'
$dummiesvm_sku = '2019-Datacenter'
$dummiesvm_os_Version = 'latest'
$dummiesvm_dns_name = 'fgedummiesvm'
$dummiesvm_VMName = 'dummiesvm'
$dummiesvm_VMSize = 'Standard_E4s_v3'
$dummiesvm_OSDiskName = 'osdisk_'+$dummiesvm_VMName
$dummiesvm_InterfaceName = 'nic_'+$dummiesvm_VMName
$dummiesvm_PipName = 'pip_'+$dummiesvm_VMName

# Public IP-Adresse anlegen
$pip_dummiesvm = New-AzPublicIpAddress `
                -Name $dummiesvm_PipName `
                -DomainNameLabel $dummiesvm_dns_name `
                -ResourceGroupName $resourcegroupName `
                -Location $location `
                -AllocationMethod Dynamic

# Netzwerk-Interface anlegen
$nic_dummiesvm = New-AzNetworkInterface `
                        -Name $dummiesvm_InterfaceName `
                        -ResourceGroupName $resourcegroupName `
                        -Location $location `
                        -SubnetId $vn.Subnets[0].Id `
                        -PublicIpAddressId $pip_dummiesvm.Id

# Jetzt wird die Konfiguration der VM angelegt
$vmConfig_dummiesvm = New-AzVMConfig `
                        -VMName $dummiesvm_VMName `
                        -VMSize  $dummiesvm_VMSize 
                      
$vmConfig_dummiesvm = Set-AzVMOperatingSystem `
                        -Windows `
                        -ComputerName $dummiesvm_VMName `
                        -Credential $Credential `
                        -VM $vmConfig_dummiesvm

$vmConfig_dummiesvm = Add-AzVMNetworkInterface `
                        -Id $nic_dummiesvm.Id
                        -VM $vmConfig_dummiesvm

$vmConfig_dummiesvm = Set-AzVMOSDisk `
                        -Name $dummiesvm_OSDiskName `
                        -CreateOption FromImage `
                        -VM $vmConfig_dummiesvm

$vmConfig_dummiesvm = Set-AzVMBootDiagnostic `
                        -Enable `
                        -ResourceGroupName $resourcegroupName `
                        -StorageAccountName $storageName ` 
                        -VM $vmConfig_dummiesvm

$vmConfig_dummiesvm = Set-AzVMSourceImage `
                        -PublisherName $dummiesvm_publisherName `
                        -Offer $dummiesvm_offer `
                        -Skus $dummiesvm_sku `
                        -Version $dummiesvm_os_Version `
                        -VM $vmConfig_dummiesvm

# virtuelle Maschine erzeugen
New-AzVM `
    -ResourceGroupName $resourcegroupName `
    -Location $location `
    -VM $vmConfig_dummiesvm